@@ -10,7 +10,7 @@ from pprint import pprint
 from datetime import datetime
 from humetools import NotImplementedAction
 
-__version__ = '1.2.9'
+__version__ = '1.2.10'
 
 class Hume():
     def __init__(self, args):
@@ -141,7 +141,7 @@ class Hume():
 def run():
     parser = argparse.ArgumentParser()
     parser.add_argument("-L", "--level",
-                        choices=['ok', 'warn', 'error', 'info', 'critical', 'debug'],
+                        choices=['ok', 'warning', 'error', 'info', 'critical', 'debug'],
                         default="info",
                         help="Level of update to send, defaults to 'info'")
     parser.add_argument("-c", "--hume-cmd",
